@@ -1,11 +1,11 @@
 # -*- coding: utf-8 -*-
 
-"""Yet another ammo generator for Yandex Tank.
+"""Yet another ammo maker for Yandex Tank.
 
 for additional info see README.md
 """
 
-__version__ = '0.1.0'
+__version__ = '0.1.1'
 __all__ = [
     'armory', 'config', 'phantom'
 ]
